/* GDA Berkeley-DB Provider
 * Copyright (C) 1998 - 2008 The GNOME Foundation
 *
 * AUTHORS:
 *         Laurent Sansonetti <lrz@gnome.org>  
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef __GDA_BDB_H__
#define __GDA_BDB_H__

/*
 * Provider name
 */
#define BDB_PROVIDER_NAME "Berkeley-DB"

/*
 * Provider's specific connection data
 */
typedef struct {
	GdaDataModel *table_model;
	gchar        *dbname;
} BdbConnectionData;

#endif
